import { CredentialProviderOptions } from "@aws-sdk/types";
import { AwsCredentialIdentityProvider, Logger } from "@smithy/types";
export declare const resolveCredentialSource: (
  credentialSource: string,
  profileName: string,
  logger?: Logger
) => (
  options?: CredentialProviderOptions
) => Promise<AwsCredentialIdentityProvider>;
